import { existsSync } from 'fs';
import { version } from 'process';
import { lightGreen } from 'kolorist';
import { createConsola } from 'consola';
import { version as version$1 } from 'os';
import { join } from 'path';

const logger = createConsola().withTag("s-info");
function showRuntimeInfo() {
  logger.log(`node: ${lightGreen(version)}`);
  logger.log(
    `platform: ${lightGreen(version$1())}`
  );
}
const CONFIG_FILE_SUFFIX = [
  ".js",
  ".mjs",
  ".ts",
  ".cjs",
  ".mts",
  ".cts"
];
async function showProjectType() {
  for (const SUFFIX of CONFIG_FILE_SUFFIX) {
    if (existsSync(join("vite.config", SUFFIX))) {
      logger.log(
        `type: ${lightGreen("vite")}`
      );
      return;
    }
    if (existsSync(join("nuxt.config", SUFFIX))) {
      logger.log(
        `type: ${lightGreen("nuxt")}`
      );
      return;
    }
  }
}
async function separate(fn) {
  console.log();
  await fn();
  console.log();
}

export { CONFIG_FILE_SUFFIX, separate, showProjectType, showRuntimeInfo };
